@@ -3,6 +3,7 @@
 
 #include <QWidget>
 
+#include <QTimer>
 #include <QDateTime>
 #include <QDate>
 
@@ -14,14 +15,20 @@
 
 typedef unsigned int Version;
 
-class ChangeManager
+class ChangeClient;
+
+class ChangeManager : public QObject
 {
+    Q_OBJECT
+
 public:
     static Version version();
     static void bump();
 
-    static bool edit(QWidget *parent, CComponent *component);
+    static void activateClient(ChangeClient *client);
+    static void deactivateClient(ChangeClient *client);
 
+    static bool edit(QWidget *parent, CComponent *component);
     static bool drop(QWidget *parent, CComponent *component);
 
     static bool newEvent(QWidget *parent);
@@ -29,17 +36,31 @@ public:
     static bool newEvent(QWidget *parent, QDateTime from, QDateTime to, bool allDay);
 
     static bool newTodo(QWidget *parent);
+    static bool newTodo(QWidget *parent, QDate due);
 
     static bool newJournal(QWidget *parent);
 
     static bool save(CComponent *component, int calendarId = -1);
 
 private:
-    static Version m_version;
+    ChangeManager();
 
-    static void addComponent(CCalendar* calendar, CComponent *component, int &error);
-    static void modifyComponent(CCalendar* calendar, CComponent *component, int &error);
-    static void deleteComponent(CCalendar *calendar, CComponent *component, int &error);
+    static ChangeManager *instance;
+
+    static Version m_version;
+    static QDate m_date;
+
+    static ChangeClient *activeClient;
+    static QTimer *dateCheckTimer;
+
+    static void addComponent(CComponent *component, int calendarId, int &error);
+    static void modifyComponent(CComponent *component, int calendarId, int &error);
+    static void deleteComponent(CComponent *component, int calendarId, int &error);
+
+private slots:
+    static void checkDate();
+
+    static void onDbChange(QString details, QString appName);
 };
 
 #endif // CHANGEMANAGER_H
