@@ -78,10 +78,9 @@ QString TodosPlug::title() const
     return tr("Tasks") + status;
 }
 
-void TodosPlug::onActivated()
+void TodosPlug::onChange()
 {
-    if (this->isOutdated())
-        reload();
+    reload();
 }
 
 void TodosPlug::reload()
@@ -238,7 +237,7 @@ void TodosPlug::cleanTodos()
             vector<CTodo*> todos = calendars[i]->getTodos(error);
             for (unsigned int t = 0; t < todos.size(); t++) {
                 if (todos[t]->getStatus())
-                    calendars[i]->deleteTodo(todos[t]->getId(), error);
+                    mc->deleteTodo(calendars[i]->getCalendarId(), todos[t]->getId(), error);
                 delete todos[t];
             }
         }
